@@ -139,6 +139,20 @@ extern int Fitsio_Pthread_Status;
 #    error "can't handle long size given by _MIPS_SZLONG"
 #  endif
 
+#elif defined(__riscv)
+
+/* RISC-V is always little endian */
+
+#define BYTESWAPPED TRUE
+
+#  if __riscv_xlen == 32
+#    define LONGSIZE 32
+#  elif __riscv_xlen == 64
+#    define LONGSIZE 64
+#  else
+#    error "can't handle long size given by __riscv_xlen"
+#  endif
+
 /* ============================================================== */
 /*  the following are all 32-bit byteswapped platforms            */
 
@@ -205,7 +219,7 @@ extern int Fitsio_Pthread_Status;
 #else
 #define BYTESWAPPED FALSE
 #endif
- 
+
 #else
 
 /*  assume all other machine uses the same IEEE formats as used in FITS files */
@@ -397,7 +411,8 @@ int fits_store_Fptr(FITSfile *Fptr, int *status);
 int fits_clear_Fptr(FITSfile *Fptr, int *status);
 int fits_already_open(fitsfile **fptr, char *url, 
     char *urltype, char *infile, char *extspec, char *rowfilter,
-    char *binspec, char *colspec, int  mode,int  *isopen, int  *status);
+    char *binspec, char *colspec, int  mode, int noextsyn,
+    int  *isopen, int  *status);
 int ffedit_columns(fitsfile **fptr, char *outfile, char *expr, int *status);
 int fits_get_col_minmax(fitsfile *fptr, int colnum, double *datamin, 
                      double *datamax, int *status);
@@ -511,6 +526,7 @@ int ffcins(fitsfile *fptr, LONGLONG naxis1, LONGLONG naxis2, LONGLONG nbytes,
 int ffcdel(fitsfile *fptr, LONGLONG naxis1, LONGLONG naxis2, LONGLONG nbytes,
            LONGLONG bytepos, int *status);
 int ffkshf(fitsfile *fptr, int firstcol, int tfields, int nshift, int *status);
+int fffvcl(fitsfile *fptr, int *nvarcols, int *colnums, int *status);
  
 int fffi1i1(unsigned char *input, long ntodo, double scale, double zero,
             int nullcheck, unsigned char tnull, unsigned char nullval, char
@@ -1098,6 +1114,9 @@ int fitsio_init_lock(void);
 
 int urltype2driver(char *urltype, int *driver);
 
+void fits_dwnld_prog_bar(int flag);
+int fits_net_timeout(int sec);
+
 int fits_register_driver( char *prefix,
 	int (*init)(void),
 	int (*fitsshutdown)(void),
@@ -1213,6 +1232,12 @@ int https_open(char *filename, int rwmode, int *driverhandle);
 int https_file_open(char *filename, int rwmode, int *driverhandle);
 void https_set_verbose(int flag);
 
+/* ftps driver I/O routines */
+int ftps_checkfile(char* urltype, char *infile, char *outfile);
+int ftps_open(char *filename, int rwmode, int *handle);
+int ftps_file_open(char *filename, int rwmode, int *handle);
+int ftps_compress_open(char *filename, int rwmode, int *driverhandle);
+
 /* ftp driver I/O routines */
 
 int ftp_checkfile(char *urltype, char *infile, char *outfile);
